@@ -1,5 +1,8 @@
 //! Simple progress bar implementations.
 //! use these or create your own!
 
-mod simple;
+pub mod simple;
 pub use simple::SimpleBar;
+
+pub mod spinny;
+pub use spinny::SpinniBuilder;
